/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.jsbuild;

import java.util.LinkedList;
import java.util.List;

/** This class outlines a JS-Module with it's name and included files
  * 
  * @author Thomas Lehmann
  *
  */
public class JsModule {
	private String name;
	private List<String> files;
	
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public List<String> getFiles() {
		return files;
	}
	public void setFiles(List<String> files) {
		this.files = files;
	}
	
	public JsModule() {
		this.name = "default";
		this.files = new LinkedList<String>();
	}
	
	public JsModule(String name){
		this();
		setName(name);
	}
	
	
	public void addFile(String file){
		this.files.add(file);
	}
	
	public String toString(){
		return "[" + this.name + "]";
	}

	public boolean equals(Object o){
		if (o == null) {
			return false;
		}
		
		if (!o.getClass().getName().equals(this.getClass().getName())) {
			return false;
		}
		
		JsModule ox = (JsModule)o;
		
		if (ox.getFiles().size() != this.files.size()) {
			return false;
		}
		
		List<String> files = ox.getFiles();
		
		for (int i=0; i<files.size(); i++){
			if (!files.get(i).equals(this.files.get(i))){
				return false;
			}
		}
		
		return true;
	}
	
}
