/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.utils;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.StringWriter;


/** A simple file helper class for reading an writing files
  * Methods here may do the same stuff Apache Commons IO do, but requiring AC/IO for reading/writing a file in such a small tool is over loaded.
  * 
  */
public class FileHelper {
	public static final int BUFFER_SIZE = 4096;
	
	/** Read file into supplied StringBuffer
 	  * @param file file to read from
 	  * @param buf StringBuffer to write file contents to
	  */
	public static void readFile(File file, StringBuffer buf) throws IOException {
		buf.append(readFileToString(file));
	}

	/** Read file and return as String
	  * @param file file to read from
	  */
	public static String readFileToString(File file) throws IOException {
		FileInputStream fis = new FileInputStream(file);
		InputStreamReader isr = new InputStreamReader(fis);
		StringWriter sw = new StringWriter();
		
		char buffer[] = new char[BUFFER_SIZE];
		int readCount;
		
		try {
			while (true) {
				readCount = isr.read(buffer, 0, BUFFER_SIZE);
				
				if (readCount <= 0) {
					break;
				}
				
				sw.write(buffer, 0, readCount);
			}
		
		} catch (IOException e) {
			throw e;
			
		} finally {
			isr.close();
			fis.close();
			sw.close();
		}
		
		return sw.toString();
	}

	/** Write a String to a file
	  * @param str string to write
	  * @param file File instance denoting a file to write to
	  */
	public static void writeFile(String str, File file) throws IOException {
		FileOutputStream fos = new FileOutputStream(file);
		
		try {
			fos.write(str.getBytes());
			
		} catch (IOException e) {
			throw e;
			
		} finally {
			fos.close();
		}		
	}
	
	/** Write a StringBuffer to a file
	  * @param buf string to write
	  * @param file File instance denoting a file to write to
	  */	
	public static void writeFile(StringBuffer buf, File file) throws IOException {
		writeFile(buf.toString(), file);
	}
}
