/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.utils;

import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;

/** Implemented multi-logger capable of composing multiple loggers together  
  * 
  * @author Thomas Lehmann
  */
public class MultiLogger implements Logger {
	
	private static MultiLogger INSTANCE = null;
	
	public static Logger getInstance(){
		if (INSTANCE == null){
			INSTANCE = new MultiLogger();
		}
		return INSTANCE;
	}
	
	private MultiLogger(){
		this.loggers = new ArrayList<Logger>();
	}
	
	protected List<Logger> loggers;
	
	protected int logLevel = LOGLEVEL_FATAL;
	
	public Logger addLogger(Logger logger){
		this.loggers.add(logger);
		return logger;
	}

	public Logger removeLogger(Logger logger){
		this.loggers.remove(logger);
		return logger;
	}
	
	
	public Logger debug(String str) {	
		for (int i = 0; i < this.loggers.size(); i++){
			this.loggers.get(i).debug(str);
		}
		return this;
	}

	public Logger error(String str) {
		for (int i = 0; i < this.loggers.size(); i++){
			this.loggers.get(i).error(str);
		}
		return this;
	}
	
	public Logger info(String str) {
		for (int i = 0; i < this.loggers.size(); i++){
			this.loggers.get(i).info(str);
		}
		return this;
	}
	
	public Logger warning(String str) {
		for (int i = 0; i < this.loggers.size(); i++){
			this.loggers.get(i).warning(str);
		}
		return this;
	}

	public Logger fatal(String str) {
		for (int i = 0; i < this.loggers.size(); i++){
			this.loggers.get(i).fatal(str);
		}
		return this;
	}

	public int getLogLevel() {
		return this.logLevel;
	}
	
	public Logger setLogLevel(int level) {
		this.logLevel = level;
		return this;
	}

	public Logger setOutputStream(OutputStream os) {
		return this;
	}


}
