/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.utils;

public class PathTool {

	/** Return relative path for given base and subject
	  * <pre>
	  * relativePath("/home/user","/home/user/.myapp/config") -> .myapp/config
	  * relativePath("/home/user","/home/user") -> .
	  * relativePath("/home/user","/home/user2/.myapp/config") -> null
	  * </pre> 
	  * @param base the path-component which is included in {subject} (starting from root)
	  * @param subject the path-component that contains sub-directories 'under' {base} to be returned in relative manner 
	  * @return the relative path component without leading or trailing slashes or '.' if {subject} had no sub-directories under {base} or null if there's no similarity
	  */
	public static String relativePath(String base, String subject){
		StringBuffer ret = null;
		
		int baseIdx = subject.indexOf(base);
		
		if (baseIdx != 0) {
			return null;
		}
		
		ret = new StringBuffer();
		ret.append(subject.substring(base.length()));
		
		// remove leading slash
		if (ret.length() >= 1 && ret.charAt(0) == '/') {
			ret.deleteCharAt(0);
		}
		
		// remove trailing slash
		if (ret.length() >= 1 && ret.charAt(ret.length()-1) == '/'){
			ret.deleteCharAt(ret.length()-1);
		}
		
		// if relative path is "CWD" (empty), return dot
		if (ret.length() == 0) {
			ret.append(".");
		}
		
		return ret.toString();
	}
	
}
