/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.utils;

import java.io.OutputStream;
import java.io.OutputStreamWriter;


/** Simple logger implementation
  * 
  * @author Thomas Lehmann
  *
  */
public class SimpleLogger implements Logger {
	private static final String PREFIX_DEBUG = "[DD] ";
	private static final String PREFIX_INFO = "[II] ";
	private static final String PREFIX_WARN = "[WW] ";
	private static final String PREFIX_ERROR = "[EE] ";
	private static final String PREFIX_FATAL = "[FF] ";

	
	public SimpleLogger(){
		logLevel = LOGLEVEL_DEBUG;
	}
	
	public boolean equals(Object o){
		return (o.getClass() == this.getClass() && 
					(((SimpleLogger) o).getOutputStream().equals(this.os)) &&
						this.logLevel == ((SimpleLogger) o).getLogLevel()); 
	}
	
	protected int logLevel = LOGLEVEL_FATAL;
	
	protected OutputStream os;
	protected OutputStreamWriter osw;
	
	protected void log(String str, int level){
		try {
			if (level >= logLevel) {
				osw.write(str + "\n");
				osw.flush();
			}
		} catch (Exception e) {
			
		}
	}		
	
	public final Logger debug(String str) {
		log(PREFIX_DEBUG + str, LOGLEVEL_DEBUG);
		return this;
	}

	public final Logger error(String str) {
		log(PREFIX_ERROR + str, LOGLEVEL_ERROR);
		return this;
	}

	public final Logger fatal(String str) {
		log(PREFIX_FATAL + str, LOGLEVEL_FATAL);
		return this;
	}

	public final Logger info(String str) {
		log(PREFIX_INFO + str, LOGLEVEL_INFO);
		return this;
	}

	public final Logger warning(String str) {
		log(PREFIX_WARN + str, LOGLEVEL_WARNING);
		return this;
	}

	
	public final Logger setLogLevel(int level) {
		this.logLevel = level;
		return this;
	}
	
	public int getLogLevel() {
		return this.logLevel;
	}


	public Logger setOutputStream(OutputStream os) {
		this.os = os;
		this.osw = new OutputStreamWriter(this.os);
		return this;
	}
	
	public OutputStream getOutputStream() {
		return this.os;
	}
}
