/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.utils;

import java.io.OutputStream;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;

/** Logger implementation for Ant-Tasks. Uses the log() methods of a task
  * 
  * @author Thomas Lehmann
  *
  */
public class TaskLogger implements Logger {
	private Task task;
	
	private TaskLogger(){
		logLevel = LOGLEVEL_DEBUG;
	}
	
	/** Initialize Logger with supplied task
 	  * @param task to bind to this logger.
	  */
	public TaskLogger(Task task){
		this();
		this.task = task;
	}
	
	public boolean equals(Object o){
		return (o.getClass() == this.getClass() && 
						this.logLevel == ((TaskLogger) o).getLogLevel()); 
	}
	
	protected int logLevel = LOGLEVEL_FATAL;
	
	protected void log(String str, int level){
		try {
			if (level >= logLevel) {
				
				if (level == LOGLEVEL_INFO) {
					task.log(str, Project.MSG_INFO);
				} else if (level == LOGLEVEL_WARNING) {
					task.log(str, Project.MSG_WARN);
				} else if (level == LOGLEVEL_ERROR || level == LOGLEVEL_FATAL) {
					task.log(str, Project.MSG_ERR);
				} else if (level == LOGLEVEL_DEBUG) {
					task.log(str, Project.MSG_DEBUG);
				} else {
					task.log(str);
				}
				
			}
		} catch (Exception e) {
			
		}
	}		
	
	public final Logger debug(String str) {
		log(str, LOGLEVEL_DEBUG);
		return this;
	}

	public final Logger error(String str) {
		log(str, LOGLEVEL_ERROR);
		return this;
	}

	public final Logger fatal(String str) {
		log(str, LOGLEVEL_FATAL);
		return this;
	}

	public final Logger info(String str) {
		log(str, LOGLEVEL_INFO);
		return this;
	}

	public final Logger warning(String str) {
		log(str, LOGLEVEL_WARNING);
		return this;
	}

	
	public final Logger setLogLevel(int level) {
		this.logLevel = level;
		return this;
	}
	
	public int getLogLevel() {
		return this.logLevel;
	}

	/** This setter is not used here
	  */
	public Logger setOutputStream(OutputStream os) {
		// unused
		return this;
	}

	/** This getter is not used here and returnes null
	  */
	public OutputStream getOutputStream() {
		return null;
	}
}
