/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.tests;

import java.io.File;
import java.io.IOException;

import org.junit.Test;
import static org.junit.Assert.*;

import de.stueckseln.buildtools.utils.FileHelper;

public class FileHelperTest {

	private static final String TESTDIRECTORY = "./target/test-resources";
	private static final String TESTFILE_PREFIX = TESTDIRECTORY + "/fileutil.";
	
	private StringBuffer generateStringBuffer(int length){
		StringBuffer buf = new StringBuffer();
		for (int i=0; i<length; i++) {
			int rnd = (i % (127 - 32)) + 32;
			buf.append((char)rnd);
		}
		return buf;
	}
	
	@Test public void writeReadFile() throws IOException {		
		File testResDir = new File(TESTDIRECTORY);
		
		System.out.println("Writing testfiles to " + testResDir.getAbsoluteFile());
		
		if (testResDir.exists() && testResDir.isFile()) {
			fail(testResDir.getAbsoluteFile() + " is not a directory");
		} else if (!testResDir.exists()) {
			testResDir.mkdir();
		}
		
		StringBuffer buf = generateStringBuffer(4095);
		String read;
		
		String str4095 = buf.toString();
		FileHelper.writeFile(buf, new File(TESTFILE_PREFIX + "strbuf.4095"));
		FileHelper.writeFile(str4095, new File(TESTFILE_PREFIX + "str.4095"));
		
		buf.append('0');
		String str4096 = buf.toString();
		FileHelper.writeFile(buf, new File(TESTFILE_PREFIX + "strbuf.4096"));
		FileHelper.writeFile(str4096, new File(TESTFILE_PREFIX + "str.4096"));
		
		buf.append('1');
		String str4097 = buf.toString();
		FileHelper.writeFile(buf, new File(TESTFILE_PREFIX + "strbuf.4097"));
		FileHelper.writeFile(str4097, new File(TESTFILE_PREFIX + "str.4097"));
		
		
		read = FileHelper.readFileToString(new File(TESTFILE_PREFIX + "strbuf.4095"));
		assertEquals("Written 4095 byte string has to equal saved string", read, str4095);
		
		read = FileHelper.readFileToString(new File(TESTFILE_PREFIX + "strbuf.4096"));
		assertEquals("Written 4096 byte string has to equal saved string", read, str4096);

		read = FileHelper.readFileToString(new File(TESTFILE_PREFIX + "strbuf.4097"));
		assertEquals("Written 4097 byte string has to equal saved string", read, str4097);
		
	}

	
	@Test public void writeNull() throws IOException {		
		StringBuffer strBufRead = new StringBuffer(), strBuf = new StringBuffer();
		FileHelper.writeFile(strBuf, new File(TESTFILE_PREFIX + "0"));
		
		FileHelper.readFile(new File(TESTFILE_PREFIX + "0"), strBufRead);
		
		assertEquals("Writing empty buffer should write zero-length file.", strBufRead.length(), 0);
		
	}
	

	@Test public void readFileToString() throws IOException {
		StringBuffer strBuf = new StringBuffer();
		String str;
		
		str = FileHelper.readFileToString(new File(TESTFILE_PREFIX + "strbuf.4097"));
		FileHelper.readFile(new File(TESTFILE_PREFIX + "strbuf.4097"), strBuf);
		
		assertEquals("String read into StringBuffer should equal directly read String.", str, strBuf.toString());
		
	}
	
}
