/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.tests;

import de.stueckseln.buildtools.utils.PathBuilder;
import de.stueckseln.buildtools.utils.SimplePathBuilder;

import org.junit.Test;
import static org.junit.Assert.*;

public class PathBuilderTest {
		
	@Test public void init(){
		PathBuilder pb = new SimplePathBuilder();
		pb.init("test");

		assertEquals("Init with one component should result in absolute path. ", "/test", pb.getPath());

		pb.init("");
		
		assertEquals("Init with empty string should result in '/'.", "/", pb.getPath());
		
		pb.init("../../abc");
		
		assertEquals("Init with parents should result in absolute path.", "/abc", pb.getPath());
		
		pb.init("./test");
		
		assertEquals("Init with 'CWD' should result in absolute path.", "/test", pb.getPath());		
		
	}
	
	@Test public void initOverflow(){
		PathBuilder pb = new SimplePathBuilder();
		pb.init("../../");
	
		assertEquals("Init with overflow should retult in '/'.", "/", pb.getPath());		
	}
	
	@Test public void append(){
		PathBuilder pb = new SimplePathBuilder();
		pb.init("/home/user");
		
		pb.append("myapp/config");
		
		assertEquals("Append should add path at end.", "/home/user/myapp/config", pb.getPath());	

	}

	@Test public void appendAbsolute(){
		PathBuilder pb = new SimplePathBuilder();
		pb.init("/home/user");
		pb.append("/var/log");
		assertEquals("Appending an absolute path should result in same absolute path.", "/var/log", pb.getPath());	
	}
	
	@Test public void parentAppend(){
		PathBuilder pb = new SimplePathBuilder();
		pb.init("/home/user");
		
		pb.append("../user2");

		assertEquals("Going up to parent should result in replaced last-folder", "/home/user2", pb.getPath());
		
		pb.append("../../var/log");
		
		assertEquals("Going up to 'root' should result in absolut path", "/var/log", pb.getPath());
	}
	
	@Test public void relativeAppend(){
		PathBuilder pb = new SimplePathBuilder();
		pb.init("/home/user");
		pb.append("./config/myapp");
		
		assertEquals("Adding 'CWD' path should resuld in appended path.", "/home/user/config/myapp", pb.getPath());
		
	}
	
	@Test public void parentOverflow(){
		PathBuilder pb = new SimplePathBuilder();
		pb.init("/tmp");
		pb.append("../../../var/log");
		
		assertEquals("Going up too high should result in path starting at 'root'", "/var/log", pb.getPath());
		
		pb.init("../var");
		pb.append("log");
		
		assertEquals("Initialiing with parent and apping should result in absolute path.", "/var/log", pb.getPath());
		
	}

	
}
