/*
This file is part of the Project JsBuild

JsBuild - http://projects.stueckseln.de/jsbuild/
JsBuild is a project released under the MIT license.


Copyright (c) 2009 Thomas Lehmann

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

package de.stueckseln.buildtools.tests;

import org.junit.Test;

import de.stueckseln.buildtools.utils.PathTool;
import static org.junit.Assert.*;

public class PathToolTest {

	@Test public void relativePath(){
		String rel;

		rel = PathTool.relativePath("/home/user", "/home/user/tmp/test");
		assertEquals("Relative path is wrong.", "tmp/test", rel);

		rel = PathTool.relativePath("/home/user/", "/home/user/tmp/test");
		assertEquals("Relative path is wrong. Cannot deal with slash-ending base.", "tmp/test", rel);

		rel = PathTool.relativePath("/home/user", "/home/user/tmp/test/");
		assertEquals("Relative path is wrong. Cannot deal with slash-ending subject.", "tmp/test", rel);

		rel = PathTool.relativePath("/home/user/", "/home/user/tmp/test/");
		assertEquals("Relative path is wrong. Cannot deal with slash-ending base and subject.", "tmp/test", rel);

		rel = PathTool.relativePath("/home/user", "/home/user");
		assertEquals("Equal base and subject have to return '.'.", ".", rel);

		rel = PathTool.relativePath("/home/user", "/home/user/tmp/test/");
		assertEquals("Relative path is wrong. Should not end with slash.", "tmp/test", rel);

		rel = PathTool.relativePath("/home/user", "home/user/tmp/test");
		assertNull("Relative subject returns not null.", rel);

		rel = PathTool.relativePath("/home/user", "../user/tmp/test");
		assertNull("Parent-relative subject returns not null.", rel);
		
		rel = PathTool.relativePath("/home/user/home/user", "/home/user/home/user/tmp/test");
		assertEquals("Relative path with multiple base-signatures is wrong.", "tmp/test", rel);

		rel = PathTool.relativePath("/home/user/home/user", "/home/user/tmp/test");
		assertNull("Subject with unmatchable base returns not null.", rel);
		
	}
	
}
